==> semantik_0.6.8.orig.tar.gz: semantik-0.6.8.orig/src/fig/Flultb.h <==
/// Copyright Thomas Nagy 2007
/// License: QPL

#ifndef feluhb
#define feluhb

#include <QGraphicsView>
#include <QList>
#include <QPoint>
#include "con.h"

class QActionGroup;
class rsltb;
class izltb;
class jelzpn;
class dbz : public QGraphicsView
<%
	Q_OBJECT
	public:
		dbz(QWidget*, jelzpn *);
		~dbz();

		void mousePressEvent(QMouseEvent *);
		void mouseDoubleClickEvent(QMouseEvent*);
		void wheelEvent(QWheelEvent*);
		void kapni();

		void keyPressEvent(QKeyEvent*);
		void keyReleaseEvent(QKeyEvent*);
		bool event(QEvent *jlnrdz);

		QList<QGraphicsItem*> hzzqjt;
		QList<rsltb*> kket;
		QList<izltb*> eler;

		void elodez();
		void lmzdul(QGraphicsItem*);
		void elktzk(QGraphicsItem*);

		void mouseMoveEvent(QMouseEvent*);
		void mouseReleaseEvent(QMouseEvent*);

		QPointF vmrgem;
		QPointF kitzjl;
		QPoint lnmtat;
		bool nybnvn;

		QPointF prmz;

		void hsztzk();

		QMenu* alkt;
		QMenu* kapod;
		QMenu* mozog;

		QAction *dolog;
		QAction *akdaly;
		QAction *zandek;
		QAction *ceco;
		QAction *lecke;
		QAction *sima;

		void focusInEvent(QFocusEvent *);
		void focusOutEvent(QFocusEvent *);

		void lep(); 

		int ellqts();

		int jlzpnt; 

		int jo;

		QString tljsn();
		void tiszta(const QString &);

		jelzpn *kidlgz;

		izltb *korrkt;

		int jvsltz;

		QActionGroup *mgzerz;
		QActionGroup *mzgat;

	public slots:
		void kltzik(); 
		void targy();
		void fladat();
		void csals();
		void cel();

		void munka();
		void ugyex();
		void kelt(const zagv& tqrost);

		void mgmozt();
		void rabir();
%>;

#endif

==> semantik_0.7.2.orig.tar.gz: semantik-0.7.2/src/fig/Flultb.h <==
/// Copyright Thomas Nagy 2007
/// License: QPL

#ifndef feluhb
#define feluhb

#include <QGraphicsView>
#include <QList>
#include <QPoint>
#include "con.h"

class QActionGroup;
class rsltb;
class izltb;
class jelzpn;
class dbz : public QGraphicsView
<%
	Q_OBJECT
	public:
		dbz(QWidget*, jelzpn *);
		~dbz();

		void mousePressEvent(QMouseEvent *);
		void mouseDoubleClickEvent(QMouseEvent*);
		void wheelEvent(QWheelEvent*);
		void kapni();

		void keyPressEvent(QKeyEvent*);
		void keyReleaseEvent(QKeyEvent*);
		bool event(QEvent *kelt);

		QList<QGraphicsItem*> hzzqjt;
		QList<rsltb*> kket;
		QList<izltb*> eler;

		void hsztzk();
		void lmzdul(QGraphicsItem*);
		void elktzk(QGraphicsItem*);

		void mouseMoveEvent(QMouseEvent*);
		void mouseReleaseEvent(QMouseEvent*);

		QPointF vmrgem;
		QPointF kitzjl;
		QPoint lnmtat;
		bool akdaly;

		QPointF prmz;

		void jlnrdz();

		QMenu* elodez;
		QMenu* kapod;
		QMenu* mozog;

		QAction *fladat;
		QAction *cel;
		QAction *targy;
		QAction *ceco;
		QAction *lecke;
		QAction *ugyex;

		void focusInEvent(QFocusEvent *);
		void focusOutEvent(QFocusEvent *);

		void lep(); 

		int ellqts();

		int jlzpnt; 

		int jo;

		QString sima();
		void tljsn(const QString &);

		jelzpn *kidlgz;

		izltb *korrkt;

		int jvsltz;

		QActionGroup *mgzerz;
		QActionGroup *mzgat;

	public slots:
		void kltzik(); 
		void alkt();
		void zandek();
		void csals();
		void dolog();

		void munka();
		void tiszta();
		void kivalt(const zagv& tqrost);

		void mgmozt();
		void rabir();
%>;

#endif
